@@ -1,5 +1,4 @@
-#! /usr/bin/env bash
-
+#!/bin/sh
 set -e
 
 # Each test script should include testlib.sh
@@ -14,9 +13,11 @@ source testlib.sh
 source confs/base.conf
 source confs/tarball.conf
 
+export TEST_FILES_SUBDIR=test
+
 export BM_ARCHIVE_ROOT="repository"
 export BM_ARCHIVE_METHOD="tarball-incremental"
-export BM_TARBALL_DIRECTORIES="$PWD"
+export BM_TARBALL_DIRECTORIES="$PWD/$TEST_FILES_SUBDIR"
 export BM_TARBALL_FILETYPE="dar"
 export BM_TARBALLINC_MASTERDATETYPE="weekly"
 export BM_TARBALLINC_MASTERDATEVALUE="1"
@@ -29,6 +30,12 @@ if [[ ! -x $dar ]]; then
 fi
 
 # The test actions
+
+rm -rf $TEST_FILES_SUBDIR
+mkdir -p $TEST_FILES_SUBDIR
+mkdir $TEST_FILES_SUBDIR/dir1
+touch $TEST_FILES_SUBDIR/file1
+
 if [[ -e $BM_ARCHIVE_ROOT ]]; then
     rm -f $BM_ARCHIVE_ROOT/*
 fi    
@@ -38,7 +45,7 @@ bm_init_today
 create_directories
 make_archives
 
-name=$(get_dir_name $PWD long)
+name=$(get_dir_name $BM_TARBALL_DIRECTORIES long)
 if [[ -e "$BM_ARCHIVE_ROOT/$BM_ARCHIVE_PREFIX$name.$TODAY.master.1.dar" ]]; then
     rm -rf $BM_ARCHIVE_ROOT
     exit 0
